NGSidekick
==========

Tools for neuroglancer scenes.

.. toctree::
   :maxdepth: 1
   :caption: API Reference:

   state_utils
   segmentprops
   annotations
   segmentcolors
   gcs
   ngvideo_helper


Installation
------------

Install ngsidekick with pip:

.. code-block:: bash

   pip install ngsidekick

For additional features:

.. code-block:: bash

   pip install ngsidekick[gcs]  # For Google Cloud Storage support
